# Kong Config Builder
[![Build Status](https://travis-ci.com/olxbr/kong-config-builder.svg?branch=master)](https://travis-ci.com/olxbr/kong-config-builder)
[![Coverage Status](https://coveralls.io/repos/github/olxbr/kong-config-builder/badge.svg?branch=master)](https://coveralls.io/github/olxbr/kong-config-builder?branch=master)

Kong declarative configuration builder.

This project translates Python files to [Kong Declarative configuration Yaml files](https://docs.konghq.com/2.0.x/db-less-and-declarative-config/). Most of times you don't need a database, just more organization.

## Install

Using Python 3.7+

```sh
pip install kong_config_builder
```

## Usage

Take a look at [Example File](https://github.com/olxbr/kong-config-builder/blob/master/create_test_config.py).

## Contribute

For development and contributing, please follow [Contributing Guide](https://github.com/olxbr/kong-config-builder/blob/master/CONTRIBUTING.md) and **ALWAYS** respect the [Code of Conduct](https://github.com/olxbr/kong-config-builder/blob/master/CODE_OF_CONDUCT.md)
